#!/bin/bash
#
# artifactory-generic-download pipe
#
# Required globals:
#   ARTIFACTORY_URL
#   ARTIFACTORY_USER
#   ARTIFACTORY_PASSWORD
#   FILE_SPEC
#   SOURCE_PATH
#   TARGET_PATH
#
# Optional globals:
#   JFROG_CLI_TEMP_DIR
#   JFROG_CLI_HOME_DIR
#   FILE_SPEC_PATH
#   COLLECT_ENV
#   COLLECT_BUILD_INFO
#   EXTRA_ARGS
#   BUILD_NAME
#

source "$(dirname "$0")/common.sh"

## Enable debug mode.
DEBUG_ARGS=
enable_debug() {
  if [[ "${DEBUG}" == "true" ]]; then
    info "Enabling debug mode."
    set -x
    DEBUG_ARGS="--verbose"
  fi
}

info "Starting pipe execution..."

# required parameters
ARTIFACTORY_URL=${ARTIFACTORY_URL:?'ARTIFACTORY_URL environment variable missing.'}
ARTIFACTORY_USER=${ARTIFACTORY_USER:?'ARTIFACTORY_USER environment variable missing.'}
ARTIFACTORY_PASSWORD=${ARTIFACTORY_PASSWORD:?'ARTIFACTORY_PASSWORD environment variable missing.'}
FILE_SPEC=${FILE_SPEC:?'FILE_SPEC environment variable missing.'}
if [[ "${FILE_SPEC}" != "true" ]]; then
  SOURCE_PATH=${SOURCE_PATH:?'SOURCE_PATH environment variable missing.'}
  TARGET_PATH=${TARGET_PATH:?'TARGET_PATH environment variable missing.'}
fi

# optional parameters
BUILD_NAME=${BUILD_NAME:=$BITBUCKET_REPO_OWNER-$BITBUCKET_REPO_SLUG-$BITBUCKET_BRANCH}
JFROG_CLI_TEMP_DIR=${JFROG_CLI_TEMP_DIR:="."}
JFROG_CLI_HOME_DIR=${JFROG_CLI_HOME_DIR:="."}
FILE_SPEC_PATH=${FILE_SPEC_PATH:="./spec.json"}
COLLECT_ENV=${COLLECT_ENV:="true"}
COLLECT_BUILD_INFO=${COLLECT_BUILD_INFO:="true"}
EXTRA_ARGS=${EXTRA_ARGS:=""}
DEBUG=${DEBUG:="false"}

debug "build name is ${BUILD_NAME}"
debug "build number is ${BITBUCKET_BUILD_NUMBER}"

# Configure Artifactory instance with JFrog CLI
run jfrog rt config --url=$ARTIFACTORY_URL --user=$ARTIFACTORY_USER --password=$ARTIFACTORY_PASSWORD --interactive=false $EXTRA_ARGS

# Run the Download command
if [[ "${FILE_SPEC}" == "true" ]]; then
  debug "Downloading artifacts using file spec provided in ${FILE_SPEC_PATH}"
  run jfrog rt dl --spec $FILE_SPEC_PATH --build-name=$BUILD_NAME --build-number=$BITBUCKET_BUILD_NUMBER $EXTRA_ARGS
else
  run jfrog rt dl $SOURCE_PATH $TARGET_PATH $EXTRA_ARGS
fi

# Capture environment variables for build information
if [[ "${COLLECT_ENV}" == "true" ]]; then
   info "Capturing environment variables"
   run jfrog rt bce $BUILD_NAME $BITBUCKET_BUILD_NUMBER $EXTRA_ARGS
fi

# Publish build information to Artifactory
if [[ "${COLLECT_BUILD_INFO}" == "true" ]]; then
   info "Capturing build information"
   run jfrog rt bp $BUILD_NAME $BITBUCKET_BUILD_NUMBER $EXTRA_ARGS
fi

if [[ "${status}" -eq 0 ]]; then
  success "Successfully downloaded artifacts from Artifactory."
else
  fail "Failed to download artifacts from Artifactory."
fi
